- realted to hrbz#877328

Signed-off-by: Jakub Filak <[email protected]>
---
 abrt.spec.in                |  9 ++-------
 po/POTFILES.in              |  1 -
 src/applet/applet.c         | 12 +++++++-----
 src/gui-gtk/Makefile.am     |  7 -------
 src/gui-gtk/abrt.desktop.in | 10 ----------
 5 files changed, 9 insertions(+), 30 deletions(-)
 delete mode 100644 src/gui-gtk/abrt.desktop.in

diff --git a/abrt.spec.in b/abrt.spec.in
index a87308d..21645bb 100644
--- a/abrt.spec.in
+++ b/abrt.spec.in
@@ -84,6 +84,7 @@ Summary: %{name}'s gui
 Group: User Interface/Desktops
 Requires: %{name} = %{version}-%{release}
 Requires: %{name}-dbus = %{version}-%{release}
+Requires: gnome-abrt
 BuildRequires: libreport-gtk-devel
 # we used to have abrt-applet, now abrt-gui includes it:
 Provides: abrt-applet = %{version}-%{release}
@@ -210,6 +211,7 @@ Requires: abrt-addon-xorg
 # Default config of addon-ccpp requires gdb
 Requires: gdb >= 7.0-3
 Requires: abrt-gui
+Requires: gnome-abrt
 Requires: abrt-plugin-bodhi
 Requires: libreport-plugin-logger, libreport-plugin-bugzilla
 Requires: libreport-plugin-ureport
@@ -266,12 +268,6 @@ mkdir -p $RPM_BUILD_ROOT/var/spool/abrt
 mkdir -p $RPM_BUILD_ROOT/var/spool/abrt-upload
 
 desktop-file-install \
-        --dir ${RPM_BUILD_ROOT}%{_datadir}/applications \
-        --vendor %{desktopvendor} \
-        --delete-original \
-        ${RPM_BUILD_ROOT}%{_datadir}/applications/%{name}.desktop
-
-desktop-file-install \
         --dir ${RPM_BUILD_ROOT}%{_sysconfdir}/xdg/autostart \
         src/applet/abrt-applet.desktop
 
@@ -524,7 +520,6 @@ gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null 
|| :
 %{_bindir}/abrt-gui
 %dir %{_datadir}/%{name}
 # all glade, gtkbuilder and py files for gui
-%{_datadir}/applications/%{desktopvendor}-%{name}.desktop
 %{_datadir}/icons/hicolor/*/apps/*
 %{_datadir}/icons/hicolor/*/status/*
 %{_datadir}/%{name}/icons/hicolor/*/status/*
diff --git a/po/POTFILES.in b/po/POTFILES.in
index d16d3e0..d0b22b6 100644
--- a/po/POTFILES.in
+++ b/po/POTFILES.in
@@ -8,7 +8,6 @@ src/daemon/abrt-server.c
 src/dbus/abrt-dbus.c
 src/daemon/abrtd.c
 src/daemon/abrt-handle-event.c
-src/gui-gtk/abrt.desktop.in
 src/gui-gtk/main.c
 src/lib/abrt_conf.c
 src/lib/hooklib.c
diff --git a/src/gui-gtk/Makefile.am b/src/gui-gtk/Makefile.am
index 270ad1b..2274a41 100644
--- a/src/gui-gtk/Makefile.am
+++ b/src/gui-gtk/Makefile.am
@@ -36,10 +36,3 @@ abrt_gui_LDADD = \
 #    ../lib/libreport.la
 
 DEFS = -DLOCALEDIR=\"$(localedir)\" @DEFS@
-
-@INTLTOOL_DESKTOP_RULE@
-desktopdir = $(datadir)/applications
-desktop_in_files = abrt.desktop.in
-desktop_DATA = $(desktop_in_files:.desktop.in=.desktop)
-
-EXTRA_DIST = $(desktop_in_files)
diff --git a/src/gui-gtk/abrt.desktop.in b/src/gui-gtk/abrt.desktop.in
deleted file mode 100644
index 0605bb9..0000000
--- a/src/gui-gtk/abrt.desktop.in
+++ /dev/null
@@ -1,10 +0,0 @@
-[Desktop Entry]
-_Name=Automatic Bug Reporting Tool
-_Comment=View and report application crashes
-Exec=abrt-gui
-Icon=abrt
-Terminal=false
-Type=Application
-Categories=System;X-Red-Hat-Base;
-StartupNotify=true
-X-Desktop-File-Install-Version=0.15
diff --git a/src/applet/applet.c b/src/applet/applet.c
index e88f0a0..001fb4a 100644
--- a/src/applet/applet.c
+++ b/src/applet/applet.c
@@ -45,6 +45,8 @@
 #define A_REPORT_REPORT "REPORT"
 #define A_REPORT_AUTOREPORT "AUTOREPORT"
 
+#define GUI_EXECUTABLE "gnome-abrt"
+
 enum
 {
     /*
@@ -448,12 +450,12 @@ static void fork_exec_gui(void)
         }
 
         /* grand child */
-        //TODO: pass s_dirs[] as DIR param(s) to abrt-gui
-        execl(BIN_DIR"/abrt-gui", "abrt-gui", (char*) NULL);
-        /* Did not find abrt-gui in installation directory. Oh well */
+        //TODO: pass s_dirs[] as DIR param(s) to 'gui executable'
+        execl(BIN_DIR"/"GUI_EXECUTABLE, GUI_EXECUTABLE, (char*) NULL);
+        /* Did not find 'gui executable' in installation directory. Oh well */
         /* Trying to find it in PATH */
-        execlp("abrt-gui", "abrt-gui", (char*) NULL);
-        perror_msg_and_die(_("Can't execute '%s'"), "abrt-gui");
+        execlp(GUI_EXECUTABLE, GUI_EXECUTABLE, (char*) NULL);
+        perror_msg_and_die(_("Can't execute '%s'"), GUI_EXECUTABLE);
     }
     else
         safe_waitpid(pid, /* status */ NULL, /* options */ 0);
-- 
1.7.11.7

Reply via email to